==> gambas_1.0.orig.tar.gz: gambas-1.0/src/lib/qt/main.h <==
/***************************************************************************

  main.h

  The interface between the QT plug-in and the Gambas interpreter

  (c) 2000-2003 Benot Minisini <gambas@users.sourceforge.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __MAIN_H
#define __MAIN_H

#include "gambas.h"

#include <qobject.h>
#include <qevent.h>
#include <qapplication.h>

#ifndef __MAIN_C
extern GB_INTERFACE GB;
extern int MAIN_in_wait;
extern int MAIN_loop_level;
#endif

class MyPostCheck: public QObject
{
  Q_OBJECT

public:

  static bool in_check;

public slots:

  void check(void);
};

/*
class MyApplication: public QApplication
{
  Q_OBJECT

public:

  static bool originalEvent;

  MyApplication( int &argc, char **argv);
  virtual bool notify( QObject *, QEvent * );
  //virtual bool eventFilter( QObject *o, QEvent *e );

private:

  bool internalNotify( QObject *, QEvent * );
};
*/

void MAIN_check_quit(void);

#endif

==> gambas_1.0.15.orig.tar.gz: gambas-1.0.15.orig/src/lib/qt/main.h <==
/***************************************************************************

  main.h

  The interface between the QT plug-in and the Gambas interpreter

  (c) 2000-2003 Benot Minisini <gambas@users.sourceforge.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 1, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

***************************************************************************/

#ifndef __MAIN_H
#define __MAIN_H

#include "gambas.h"

#include <qobject.h>
#include <qevent.h>
#include <qapplication.h>

#define DO_NOT_USE_QT_INTERFACE

#ifndef __MAIN_CPP
extern GB_INTERFACE GB;
extern int MAIN_in_wait;
extern int MAIN_loop_level;
#endif

class MyPostCheck: public QObject
{
  Q_OBJECT

public:

  static bool in_check;

public slots:

  void check(void);
};

/*
class MyApplication: public QApplication
{
  Q_OBJECT

public:

  static bool originalEvent;

  MyApplication( int &argc, char **argv);
  virtual bool notify( QObject *, QEvent * );
  //virtual bool eventFilter( QObject *o, QEvent *e );

private:

  bool internalNotify( QObject *, QEvent * );
};
*/

#define UTF8_NBUF 4

void MAIN_check_quit(void);
const char *QT_ToUTF8(const QString &str);

#endif
